@@ -59,9 +59,9 @@ class ProvPopTable(pd.DataFrame):
         flag: bool = True
     ):
         '''
-        Create an instance of ProvPopTable. Note that any components having
-        a negative impact on population growth (e.g. deaths) must have
-        non-positive values.
+        Create an instance of ProvPopTable. Note that every cell of the 
+        table except for those in the end-of-period population column 
+        should have non-negative values.
 
         Usage
         -----
@@ -731,7 +731,8 @@ class ProvPopTable(pd.DataFrame):
             comp_L = '{0}_L'.format(comp)
             L = self_copy.get_L(comp, method)
             if return_all_mods or (comp in interprovs):
-                comps_modified.append(L)
+                if any(L[comp_L].values != 0):
+                    comps_modified.append(L)
             L['Age'] = L['Age'].apply(str)
             self_copy['Age'] = self_copy['Age'].apply(str)
             self_copy = self_copy.merge(L, on = pop_groups, how = 'left')
