@@ -14,6 +14,7 @@ from estime2 import (
     ProvPopTable
 )
 from estime2.provpoptable import calculate_ages_to_modify_and_counter
+from pprint import pprint
 import numpy as np
 import os
 import pandas as pd
@@ -506,7 +507,10 @@ def run3():
     print(poptbl)
     print(poptbl.calculate_pop())
 
-    result = poptbl.fix_issues()
-    print(result)
-    print(result.calculate_pop())
+    result = poptbl.fix_issues(return_all_mods = True)
+    pprint(result)
+    try:
+        print(result.calculate_pop())
+    except:
+        print(result[0].calculate_pop())
     # return result
